@@ -24,20 +24,3 @@ RUN_LABEL_IMAGE = "VSI_NN_LOG_LEVEL=0 {0} -m {1} -t 1 -i {2} -l {3} -a {4} -v 0
 
 REGEX_GET_INTEGER_FLOAT = "\d+\.\d+|\d+"
 REGEX_GET_STRING = "[^a-zA-Z\s]"
-
-# ML Player
-
-MAIN_WINDOW_TITLE = "PyeIQ ML Player"
-
-DEFAULT_DEMOS_DIR = "/opt/eiq/demos"
-DEFAULT_DEMOS_DESCRIPTION = "Demos\nDescription"
-
-DEFAULT_IMAGE = "/usr/bin/tensorflow-lite-2.1.0/examples/grace_hopper.bmp"
-DEFAULT_IMAGE_HEIGHT = 400
-DEFAULT_IMAGE_WIDTH = 300
-
-RUN_DEMO = "python3 /opt/eiq/demos/{} -i {}"
-
-ALIGN_LEFT = 0.0
-ALIGN_CENTER = 0.5
-ALIGN_RIGHT = 1.0
